.. _require_python_module:

:mod:`fabtools.require.python`
------------------------------

.. automodule:: fabtools.require.python

    .. seealso:: :ref:`python_module`

    Virtual environments
    ~~~~~~~~~~~~~~~~~~~~

    .. autofunction:: virtualenv

    Installing packages
    ~~~~~~~~~~~~~~~~~~~

    .. autofunction:: package
    .. autofunction:: packages
    .. autofunction:: requirements
    .. autofunction:: pip
    .. autofunction:: setuptools
